( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.Czech )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.Czech hyphen.Czech )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.dutch )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.dutch hyphen.dutch )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.finish )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.finish hyphen.finish )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.french )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.french hyphen.french )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.german )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.german hyphen.german )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.polish )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.polish hyphen.polish )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.portug )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.portug hyphen.portug )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.spanish )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.spanish hyphen.spanish )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.swedish )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.swedish hyphen.swedish )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.ukenglish )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.ukenglish hyphen.ukenglish )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf hyphen.us )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/hyphen.us hyphen.us )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf tkhypha.tex )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/tkhypha.tex tkhypha.tex )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf tkhyphart.tex )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/tkhyphart.tex tkhyphart.tex )
( cd usr/lib/texmf/tex/hyphenation ; rm -rf turk_hyf.c )
( cd usr/lib/texmf/tex/hyphenation ; ln -sf /cdrom/live/usr/lib/texmf/tex/hyphenation/turk_hyf.c turk_hyf.c )
